@@ -49,4 +49,8 @@ def bool_is_rule(ampt, rule, thd):
     if(rule == '<='):
         return ampt <= thd
     if(rule == '<'):
-        return ampt < thd
\ No newline at end of file
+        return ampt < thd
+
+def df_drop_columns_except(df, exception):
+    df_out = df.loc[:, df.columns.isin(exception)]
+    return df_out
\ No newline at end of file
